WrapperMut

Trait WrapperMut 

pub trait WrapperMut<T>: Wrapper<T> {
    // Required methods
    fn get_mut(&mut self) -> &mut T;
    fn view_mut(&mut self) -> Self::Cont<&mut T>;
}
The WrapperMut trait extends the Wrapper trait to provide mutable access to the inner value.

Required Methods

fn get_mut(&mut self) -> &mut T

returns a mutable reference to the inner value

fn view_mut(&mut self) -> Self::Cont<&mut T>

returns a view of the container containing a mutable reference to the inner value

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors